package com.xtd.project.system.service;

import java.util.List;
import com.xtd.project.system.domain.DbSupplier;
import com.xtd.project.system.domain.vo.SelectVo;

/**
 * 供应商Service接口
 *
 * @author xtd
 * @date 2020-04-07
 */
public interface IDbSupplierService
{
    /**
     * 查询供应商
     *
     * @param sId 供应商ID
     * @return 供应商
     */
    public DbSupplier selectDbSupplierById(Long sId);

    /**
     * 查询供应商列表
     *
     * @param dbSupplier 供应商
     * @return 供应商集合
     */
    public List<DbSupplier> selectDbSupplierList(DbSupplier dbSupplier);

    /**
     * 新增供应商
     *
     * @param dbSupplier 供应商
     * @return 结果
     */
    public int insertDbSupplier(DbSupplier dbSupplier);

    /**
     * 修改供应商
     *
     * @param dbSupplier 供应商
     * @return 结果
     */
    public int updateDbSupplier(DbSupplier dbSupplier);

    /**
     * 批量删除供应商
     *
     * @param sIds 需要删除的供应商ID
     * @return 结果
     */
    public int deleteDbSupplierByIds(Long[] sIds);

    /**
     * 删除供应商信息
     *
     * @param sId 供应商ID
     * @return 结果
     */
    public int deleteDbSupplierById(Long sId);

    List<SelectVo> selectList();
}
